/**
 * \file grouping/ptm/ptmsamplescan.cpp
 * \date 23/7/2017
 * \author Olivier Langella
 * \brief collection of PTM peptides sharing the same spectrum (sample scan)
 */

/*******************************************************************************
* Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/

#include "ptmsamplescan.h"

PtmSampleScan::PtmSampleScan(const PeptideMatch * p_peptide_match) {
    _peptide_match_list.push_back(p_peptide_match);
}

PtmSampleScan::PtmSampleScan(const PtmSampleScan& other){
}

PtmSampleScan::~PtmSampleScan() {
}
const PeptideMatch * PtmSampleScan::getRepresentativePeptideMatch() const {
    return _peptide_match_list[0];
}
bool PtmSampleScan::add(const PeptideMatch * p_peptide_match) {
    if(getRepresentativePeptideMatch()->getHashSampleScan() != p_peptide_match->getHashSampleScan()) {
        return false;
    }
    if(getRepresentativePeptideMatch()->getPeptideXtpSp().get()->getSequence() != p_peptide_match->getPeptideXtpSp().get()->getSequence()) {
        return false;
    }
    if(getRepresentativePeptideMatch()->getPeptideXtpSp().get()->getMass() != p_peptide_match->getPeptideXtpSp().get()->getMass()) {
        return false;
    }
    _peptide_match_list.push_back(p_peptide_match);
    return true;
}
